# BMPM (Botw Map Parameter Manipulator)
 A script for manipulating parameters contained within BotW's map files in bulk.

# Installation
 Copy the ".exe" file to C:/Users/(username)/AppData/local/Programs/Python/scripts/ OR add the directory containing the compiled script to your PATH (Please note that the exe is not up to date)
 <br>
 OR
 <br>
 Use the command "pip install bmpm" from the cli to automatically install the and setup necessarry files
 <br>
 OR
 <br>
 Download a zip of the code and run "python setup.py install" from the cli within the directory containing the files to install and setup the files

# Usage
 The batch file included is for recursively going through directories and editing all "LevelSensorMode" parameters to 1
 For more information on how to use the script, type "bymlMapParamEditor -h" or "bymlMapParamEditor --help"
